var indexSectionsWithContent =
{
  0: "abcdefghiklmnopqrstuvwxyz~",
  1: "cfprsu",
  2: "l",
  3: "bcfgoprstu",
  4: "abcdefghimnopqrstuv~",
  5: "abcdefghklmnoprstuvwxy",
  6: "bcdimt",
  7: "acdefhlmnoprsty",
  8: "abcdefghiklmnorstv",
  9: "l",
  10: "aclmrst"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "defines",
  10: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Macros",
  10: "Pages"
};

